/*
 * Copyright © 2009 Henri Häkkinen.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <libnotify/notify.h>
#include "terminal-app.h"
#include "terminal-profile.h"
#include "terminal-notify.h"

gboolean
terminal_notification_show (TerminalProfile          *profile,
                            TerminalNotificationType  type)
{
  NotifyNotification *notif;
  gint                timeout;
  const gchar        *summary;
  const gchar        *body;
  const gchar        *category;
  NotifyUrgency       urgency;

  if (!terminal_profile_get_property_boolean (profile, TERMINAL_PROFILE_LIBNOTIFY_ENABLE))
    return TRUE;

  timeout =
    terminal_profile_get_property_int (profile, TERMINAL_PROFILE_LIBNOTIFY_TIMEOUT);

  summary =
    terminal_profile_get_property_string (profile, TERMINAL_PROFILE_LIBNOTIFY_SUMMARY);

  category =
    terminal_profile_get_property_string (profile, TERMINAL_PROFILE_LIBNOTIFY_CATEGORY);

  urgency =
    terminal_profile_get_property_int (profile, TERMINAL_PROFILE_LIBNOTIFY_URGENCY);

  switch (type)
    {
    case TERMINAL_NOTIFICATION_TYPE_ACTIVITY:
      body =
        terminal_profile_get_property_string (profile, TERMINAL_PROFILE_LIBNOTIFY_BODY1);
      break;
    case TERMINAL_NOTIFICATION_TYPE_INACTIVITY:
      body =
        terminal_profile_get_property_string (profile, TERMINAL_PROFILE_LIBNOTIFY_BODY2);
      break;
    default:
      g_return_val_if_reached (FALSE);
    }

  notif = notify_notification_new (summary, body, GNOME_TERMINAL_ICON_NAME, NULL);
  g_return_val_if_fail (notif, FALSE);

  notify_notification_set_timeout (notif, timeout);
  notify_notification_set_category (notif, category);

  if (!notify_notification_show (notif, NULL))
    return FALSE;

  g_object_unref (notif);
  return TRUE;
}
